From 5dc479691327a48236fe0c50b94714bdb9fda28f Mon Sep 17 00:00:00 2001
From: Dirk Mueller <dmueller@suse.com>
Date: Tue, 11 Jun 2013 16:51:44 +0200
Subject: [PATCH] [armv7hl] Add arm-7742-1-topology-export-cpu_topology.patch

---
 .../arm-7742-1-topology-export-cpu_topology.patch  | 51 ++++++++++++++++++++++
 series.conf                                        |  1 +
 2 files changed, 52 insertions(+)
 create mode 100644 patches.arch/arm-7742-1-topology-export-cpu_topology.patch

diff --git a/patches.arch/arm-7742-1-topology-export-cpu_topology.patch b/patches.arch/arm-7742-1-topology-export-cpu_topology.patch
new file mode 100644
index 0000000..81d789a
--- /dev/null
+++ b/patches.arch/arm-7742-1-topology-export-cpu_topology.patch
@@ -0,0 +1,51 @@
+Patch-mainline: Queued for upstream
+Git-commit: 92bdd3f5eba299b33c2f4407977d6fa2e2a6a0da
+
+From 92bdd3f5eba299b33c2f4407977d6fa2e2a6a0da Mon Sep 17 00:00:00 2001
+From: Arnd Bergmann <arnd@arndb.de>
+Date: Fri, 31 May 2013 22:49:22 +0100
+Subject: ARM: 7742/1: topology: export cpu_topology
+
+From: Arnd Bergmann <arnd@arndb.de>
+
+commit 92bdd3f5eba299b33c2f4407977d6fa2e2a6a0da upstream.
+
+The cpu_topology symbol is required by any driver using the topology
+interfaces, which leads to a couple of build errors:
+
+ERROR: "cpu_topology" [drivers/net/ethernet/sfc/sfc.ko] undefined!
+ERROR: "cpu_topology" [drivers/cpufreq/arm_big_little.ko] undefined!
+ERROR: "cpu_topology" [drivers/block/mtip32xx/mtip32xx.ko] undefined!
+
+The obvious solution is to export this symbol.
+
+Signed-off-by: Arnd Bergmann <arnd@arndb.de>
+Acked-by: Will Deacon <will.deacon@arm.com>
+Cc: Nicolas Pitre <nico@linaro.org>
+Cc: Vincent Guittot <vincent.guittot@linaro.org>
+Signed-off-by: Russell King <rmk+kernel@arm.linux.org.uk>
+Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
+Signed-off-by: Dirk Mueller <dmueller@suse.com>
+
+---
+ arch/arm/kernel/topology.c |    2 ++
+ 1 file changed, 2 insertions(+)
+
+--- a/arch/arm/kernel/topology.c
++++ b/arch/arm/kernel/topology.c
+@@ -13,6 +13,7 @@
+ 
+ #include <linux/cpu.h>
+ #include <linux/cpumask.h>
++#include <linux/export.h>
+ #include <linux/init.h>
+ #include <linux/percpu.h>
+ #include <linux/node.h>
+@@ -200,6 +201,7 @@ static inline void update_cpu_power(unsi
+  * cpu topology table
+  */
+ struct cputopo_arm cpu_topology[NR_CPUS];
++EXPORT_SYMBOL_GPL(cpu_topology);
+ 
+ const struct cpumask *cpu_coregroup_mask(int cpu)
+ {
diff --git a/series.conf b/series.conf
index 14c6184..980b935 100644
--- a/series.conf
+++ b/series.conf
@@ -160,6 +160,7 @@
 	patches.arch/arm-imx-usb.patch
 	patches.arch/arm-omap3isp.patch
 	patches.arch/arm-smdkv310.patch
+	patches.arch/arm-7742-1-topology-export-cpu_topology.patch
 	# Compile fix for Xen on ARM with our Xen patches applied
 	patches.arch/arm-xen-fixup.patch
 
-- 
1.8.1.4

